Struct security_framework::os::macos::keychain::KeychainSettings [−][src]
pub struct KeychainSettings(_);
Settings associated with a SecKeychain.
Implementations
impl KeychainSettings[src]
impl KeychainSettings[src]pub fn new() -> KeychainSettings[src]
pub fn new() -> KeychainSettings[src]Creates a new KeychainSettings with default settings.
pub fn set_lock_on_sleep(&mut self, lock_on_sleep: bool)[src]
pub fn set_lock_on_sleep(&mut self, lock_on_sleep: bool)[src]If set, the keychain will automatically lock when the computer sleeps.
Defaults to false.
pub fn set_lock_interval(&mut self, lock_interval: Option<u32>)[src]
pub fn set_lock_interval(&mut self, lock_interval: Option<u32>)[src]Sets the interval of time in seconds after which the keychain is automatically locked.
Defaults to None.